*version 10

set mem 30m
set matsize 200
use "C:\Documents and Settings\Mark\My Documents\_Projects\EconVote\PerfPress_Replication_080404.dta" 
cd "C:\Documents and Settings\Mark\My Documents\_Projects\EconVote\"


exit





*-----------------------*
//Table 1 - Indiv Level//
*-----------------------*
use "PerfPress_Indiv_Small_090119.dta"
set more off
*--------PID Merged---------*
xi: logit vote1 PID rGDPr PIDXrGDPr
est2vec table1, e(N N_g r2 chi2) vars(PID rGDPr PIDXrGDPr rightgov sex sex*rightgov income income*rightgov education edu*rightgov _cons) name(NoFE) replace
xi: logit vote1 PID rGDPr PIDXrGDPr i.cnum
est2vec table1, addto(table1) name(C-FE)
xi: logit vote1 PID rGDPr PIDXrGDPr i.cnum i.eb
est2vec table1, addto(table1) name(C-EB-FE)
xi3: logit vote1 PID rGDPr PIDXrGDPr sex*rightgov age*rightgov income12cat*rightgov educ*rightgov i.cnum
est2vec table1, addto(table1) name(C-FE-plus)
est2tex table1, mark(stars) preserve fancy dropall replace





*---------------------------------*
//TABLE 2  Agg Level, no controls//
*---------------------------------*
use "C:\Documents and Settings\Mark\My Documents\_Projects\EconVote\PerfPress_Replication_080404.dta" 
set more off
*--------PID Merged---------*
xi: xtpcse votegov4 rGDPr PIDavg rGDPrXPIDavg i.ccode if nation<10, corr(ar1) pairwise
est2vec table1_CPS, e(N N_g r2 chi2) vars(rGDPr PIDavg rGDPrXPIDavg PID1 rGDPrXPID1 _cons) name(PIDavg) replace
xi: xtpcse votegov4 rGDPr PID1 rGDPrXPID1 i.ccode if nation<10, corr(ar1) pairwise
est2vec table1_CPS, addto(table1_CPS) name(PID1)
est2tex table1_CPS, mark(stars) preserve fancy dropall replace



*----------------------------*
//Table 3 - clarity controls//
*----------------------------*
use  "C:\Documents and Settings\Mark\My Documents\_Projects\EconVote\EconVote_Agg_050810.dta"
#delimit;
set more off;
xi3: xtpcse votegov4 rGDPr PIDavg rGDPrXPIDavg rGDPr*fraction rGDPr*nb_party rGDPr*pct_coal rGDPr*ideocoal i.nation, 
	corr(ar1) pairwise;
est2vec table1, e(N N_g r2 chi2) vars(rGDPr PIDavg rGDPrXPIDavg PID1 rGDPrXPID1 fraction _IrGXfr nb_party _IrGXnb 
	pct_coal _IrGXpc ideocoal _IrGXid  _cons) name(PIDavg) replace;
xi3: xtpcse votegov4 rGDPr PID1 rGDPrXPID1 rGDPr*fraction rGDPr*nb_party rGDPr*pct_coal rGDPr*ideocoal i.nation, 
	corr(ar1) pairwise;
est2vec table1, addto(table1) name(PID1);

est2tex table1, preserve fancy dropall replace;


*PIDavg: Marginal effect of rGDPr with all interaction vars set at means:
di -1.438 - 2.961*2.02 +.360*1.874+.429*4.79+.077*53.41+1.971*.85
* 1.098

*PIDavg: Marginal effect of rGDPr with all interaction vars set at means:
di -1.420 + .027*37.367 +.185*1.874+.219*4.791+.022*53.41-1.276*.85
*1.075


*---------------------*
// Table 3: Validity //
*---------------------*

* NOTE: TABLE 2 USES THE PerfPress_Agg_050810.dta FILE THAT HAS DATA AFTER 1992.  THIS RAISES THE INCUSHARE N FROM 42 TO 52.
use  "C:\Documents and Settings\Mark\My Documents\_Projects\EconVote\PerfPress_Agg_050810.dta"
xi3: reg incushare votegov4*abstimegap
outtex
sum abstimegap if votegov4~=. & incushare~=., d
corr incushare votegov4 if abstimegap<=31




*----------------------------*
// Summary Statistics Table //
*----------------------------*

sutex sum votegov4 PIDavg PID1 rGDPr fraction nb_party pct_coal ideocoal if votegov4~=. & year<1993 & PID1~=.

*--------------------------*
//	 Figures 2 and 3    //
*--------------------------*

set scheme s1mono, permanently
sort nation date
line PIDavg date if year<1993, by(cname) xlabel(40 60) ytitle("Mean Partisan Attachment")
line PID1 date if year<1993, by(cname) xlabel(40 60) ytitle("Percent Nonpartisan")




/*-----------------------------------------------------------*/
/*			FIGURE XXX Interaction Effects		 */
/*-----------------------------------------------------------*/

*use "PerfPress_Indiv_Small_090119.dta"

set more off
gen PIDcat = . 
gen pest = .
gen cihi = .
gen cilo = .

forvalues cat = 1/4 {


	//need equation for every PID level to get right se for each cat//
	capture xi3: logit vote1 PID rGDPr PIDXrGDPr //i.cnum //
	lincom rGDPr + PIDXrGDPr*`cat'
	di r(estimate)

	matrix b=e(b)
	matrix V=e(V)

	scalar b1=b[1,1]
	scalar b2=b[1,2]
	scalar b3=b[1,3]

	scalar varb1=V[1,1]
	scalar varb2=V[2,2]
	scalar varb3=V[3,3]

	scalar covb1b3=V[1,3]
	scalar covb2b3=V[2,3]

	scalar list b1 b2 b3 varb1 varb3 covb1b3 covb2b3


		replace pest = b1+b3*(`cat') if _n==`cat' //point estimate//
		replace cihi = pest + 1.96*r(se) if _n==`cat'
		replace cilo = pest - 1.96*r(se) if _n==`cat'
		*di "cihi = " cihi
		*di "cilo = " cilo
	

	replace PIDcat = `cat' if _n==`cat'

}

list pest cihi cilo PIDcat in 1/5

graph twoway rspike cihi cilo PIDcat, lcolor(black) xscale(range(0 5)) xtick(1 2 3 4) xlabel(1(1)4 1 "not close" 2"sympathizer" 3"fairly close" 4"very close")/*
	*/ || scatter pest PIDcat, mcolor(black) legend(off) xtitle(" ") yline(0)

gr save econvote_4PID_lincom, replace

drop pest cihi cilo PIDcat





*------------------------------------*
//Figure 4 - Indiv Level Pred Probs //
*------------------------------------*

xi3: logit vote1 PID rGDPr PIDXrGDPr

gen MV =(_n-10)/5
replace MV =. if _n>40
label var MV "growth"

matrix b=e(b)
scalar b1=b[1,1]
scalar b2=b[1,2]
scalar b3=b[1,3]
scalar b0=_b[_cons]
scalar list b1 b2 b3 b0

gen p1= 1/(1+exp(-b0 - b1*1 - b2*MV - b3*1*MV))
gen p2= 1/(1+exp(-(b0 + b1*2 + b2*MV + b3*2*MV)))
gen p3= 1/(1+exp(-(b0 + b1*3 + b2*MV + b3*3*MV)))
gen p4= 1/(1+exp(-(b0 + b1*4 + b2*MV + b3*4*MV)))

gr twoway line p1 MV, lpattern(dot)|| line p2 MV, lpattern (dash_dot) /*
*/ || line p3 MV, lpattern(dash) || line p4 MV, lpattern(solid) legend(off)
drop p1-p4 MV





*------------------------------------------------------------------*
//			Fig 5: Predicted Value Plots, Model 1.1		//
*------------------------------------------------------------------*

xi: xtpcse votegov4 rGDPr PIDavg rGDPrXPIDavg i.ccode if nation<10, corr(ar1) pairwise

replace votegovhat76DE = _b[_cons] + _b[rGDPr]*rGDPr + _b[PIDavg]*2.05 + _b[rGDPrXPIDavg]*rGDPr*2.05 + _b[_Iccode_5] //note: uses German fixed effect//
replace votegovhat92DE = _b[_cons] + _b[rGDPr]*rGDPr + _b[PIDavg]*1.93 + _b[rGDPrXPIDavg]*rGDPr*1.93 + _b[_Iccode_5]
graph twoway line votegovhat76DE rGDPr, lpattern(dash) lcolor(black)|| line votegovhat92DE rGDPr, lwidth(thick) legend(off) lcolor(black)




*------------------------------------------*
// Fig 6a: PIDavg Marginal Effects Figure //
*------------------------------------------*
#delimit;
drop MV conb conse  cihi cilo;

xi: xtpcse votegov4 rGDPr PIDavg rGDPrXPIDavg i.nation if nation<10, corr(ar1) pairwise;

generate MV = ((_n-1)/10);

replace MV=. if _n> 31;

matrix b=e(b);
matrix V=e(V);

scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];

scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];

scalar covb1b3=V[1,3];
scalar covb2b3=V[2,3];

scalar list b1 b2 b3 varb1 varb3 covb1b3 covb2b3;

gen conb=b1+b3*MV if _n<=31;

gen conse=sqrt(varb1+ varb3*(MV^2)+2*covb1b3*MV) if _n<=31;

gen cihi=conb+1.96*conse;

gen cilo=conb-1.96*conse;

graph twoway line conb cihi cilo MV if MV>=1.5 & MV<=2.3, lcolor(black black black) lwidth(thick medium medium) 
	lpattern (solid dash dash) xtitle("Mean Partisan Attachment") legend(off) yline(0) 
	xscale(range(1.5 (.1) 2.3)) xlabel(1.5 (.2) 2.3); //Note that range really controlled by if statement//;


gr save ME_PIDavg.gph, replace;


*----------------------------------------*
//  Fig 6b: PID1 Marginal Effects Figure//
*----------------------------------------*
#delimit;
drop MV conb conse  cihi cilo;


xi: xtpcse votegov4 rGDPr PID1 rGDPrXPID1 i.ccode if nation<10, corr(ar1) pairwise;

generate MV = ((_n-1)+10);
replace MV=. if _n> 60;

matrix b=e(b);
matrix V=e(V);

scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];

scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];

scalar covb1b3=V[1,3];
scalar covb2b3=V[2,3];

scalar list b1 b2 b3 varb1 varb3 covb1b3 covb2b3;

gen conb=b1+b3*MV if _n<=60;

gen conse=sqrt(varb1+ varb3*(MV^2)+2*covb1b3*MV) if _n<=60;

gen cihi=conb+1.96*conse;

gen cilo=conb-1.96*conse;

graph twoway line conb cihi cilo MV if MV>=12 & MV<=54, lcolor(black black black) lwidth(thick medium medium) 
	lpattern (solid dash dash) xtitle("Percent Nonpartisan") legend(off) yline(0) 
	xscale(range(12 (1) 54)) xlabel(12 (10) 54); //Note that range really controlled by if statement//;


gr save ME_PID1, replace;

gr combine ME_PIDavg.gph ME_PID1.gph;





















